"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function kiUnits(value) {
    if (typeof value === 'string') {
        value = parseFloat(value);
    }
    return value * 11;
}
function flatten(arr) {
    return [].concat.apply([], arr);
}
function convertNoConnect(args) {
    var pinDotX = args[0], pinDotY = args[1], id = args[2], pathStr = args[3], color = args[4], locked = args[5];
    var kiUnitX = kiUnits(pinDotX);
    var kiUnitY = kiUnits(pinDotY);
    var result = [];
    result.push("NoConn ~ " + kiUnitX + " " + kiUnitY);
    return result;
}
function convertJunction(args) {
    var pinDotX = args[0], pinDotY = args[1], junctionCircleRadius = args[2], fillColor = args[3], id = args[4], locked = args[5];
    var kiUnitX = kiUnits(pinDotX);
    var kiUnitY = kiUnits(pinDotY);
    var result = [];
    result.push("Connection ~ " + kiUnitX + " " + kiUnitY);
    return result;
}
function convertWire(args) {
    var points = args[0], strokeColor = args[1], strokeWidth = args[2], strokeStyle = args[3], fillColor = args[4], id = args[5], locked = args[6];
    var coordList = points.split(' ');
    var result = [];
    for (var i = 0; i < coordList.length - 2; i += 2) {
        result.push('Wire Wire Line');
        result.push('    ' +
            coordList
                .slice(i, i + 4)
                .map(kiUnits)
                .join(' '));
    }
    return result;
}
function convertShape(shape) {
    var _a = shape.split('~'), type = _a[0], args = _a.slice(1);
    switch (type) {
        case 'W':
            return convertWire(args);
        case 'J':
            return convertJunction(args);
        case 'O':
            return convertNoConnect(args);
        default:
            console.warn("Warning: unsupported shape " + type);
            return [];
    }
}
exports.convertShape = convertShape;
function convertSchematic(input) {
    var schematics = input.schematics;
    if (schematics.length !== 1) {
        console.warn("Found " + schematics.length + " schematics, converting only the first one.");
    }
    var schematic = JSON.parse(schematics[0].dataStr);
    var shapeArray = schematic.shape;
    var shapeResult = flatten(shapeArray.map(convertShape)).join('\n');
    return ("\nEESchema Schematic File Version 4\nEELAYER 30 0\nEELAYER END\n" + shapeResult + "\n$EndSCHEMATC\n").trim();
}
exports.convertSchematic = convertSchematic;
//# sourceMappingURL=schematic.js.map